
API reference
~~~~~~~~~~~~~

#. :doc:`PyRanges objects <./pyranges_objects>` are the main data structure in pyranges
#. :doc:`The pyranges module <./pyranges_module>` offer file readers and other utilities
#. :doc:`Extensions submodules <./pyranges_extensions>` provide additional domain-specific functionalities
#. :doc:`RangeFrame <./range_frame>` is the parent class of PyRanges, supporting operations on simple intervals

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   pyranges_objects
   pyranges_module
   pyranges_extensions
   range_frame
